#
# spec file for package rk
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname lib%{name}0
Name:           rk
Version:        1.8
Release:        1.1
Summary:        A C++ library for relativistic kinematics
License:        X11
Group:          Development/Libraries/C and C++
URL:            https://rk.hepforge.org/
Source:         http://www.hepforge.org/archive/%{name}/%{name}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
%{name} provides a C++ double precision implementation of several
basic geometric entities and transformations: points in 3d,
directions in 3d (unit vectors), 3-vectors, points in 4d,
4-vectors, rotations, linear transformations, and boosts. The main
purpose of the package is representing 4-momenta of relativistic
particles and related formulae.

%package -n %{soname}
Summary:        A C++ library for relativistic kinematics
Group:          Development/Libraries/C and C++

%description -n %{soname}
%{name} provides a C++ double precision implementation of several
basic geometric entities and transformations: points in 3d,
directions in 3d (unit vectors), 3-vectors, points in 4d,
4-vectors, rotations, linear transformations, and boosts. The main
purpose of the package is representing 4-momenta of relativistic
particles and related formulae.

This package provides the shared libraries required for %{name}.

%package devel
Summary:        A C++ library for relativistic kinematics
Group:          Development/Libraries/C and C++
Requires:       %{soname} = %{version}

%description devel
%{name} provides a C++ double precision implementation of several
basic geometric entities and transformations: points in 3d,
directions in 3d (unit vectors), 3-vectors, points in 4d,
4-vectors, rotations, linear transformations, and boosts. The main
purpose of the package is representing 4-momenta of relativistic
particles and related formulae.

This package provides the source files required for development
with %{name}.

%prep
%autosetup

%build
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{soname} -p /sbin/ldconfig
%postun -n %{soname} -p /sbin/ldconfig

%files devel
%license LICENSE
%doc AUTHORS NEWS
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc

%files -n %{soname}
%{_libdir}/*.so.*

%changelog
* Fri Oct 13 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.8:
  * Added a constructor from two P4 objects to the rk::Boost
    class.
  * Added a few "const" qualifiers to various arguments as
    appropriate.
- Specfile cleanups with spec-cleaner.
- Use %%license for LICENSE file.
* Mon Jun  7 2021 Jan Engelhardt <jengelh@inai.de>
- Drop --with-pic (no effect with --disable-static)
- Upgrade old rpm constructs
* Wed Aug  2 2017 badshah400@gmail.com
- Update to version 1.7:
  * Added methods "beta", "gamma", "betaGamma", and "velocity" to
    the rk::Boost class.
  * Added function "rk::transformVelocity".
* Sun Mar 15 2015 p.drouand@gmail.com
- Update to version 1.6
  * Added transverse() function to P4
* Tue Apr 22 2014 cfarrell@suse.com
- license update: X11
  The license described is X11, not MIT (see spdx.org/licenses/X11)
* Sun Apr 13 2014 badshah400@gmail.com
- Initial package (version 1.5)
